@@ -1,5 +1,5 @@
 /*
- * Logswan 2.1.4
+ * Logswan 2.1.8
  * Copyright (c) 2015-2020, Frederic Cambus
  * https://www.logswan.org
  *
@@ -10,7 +10,7 @@
  * See LICENSE file for details.
  */
 
-char *methodsNames[] = {
+const char *methodsNames[] = {
 	"GET",
 	"POST",
 	"HEAD",
@@ -22,9 +22,9 @@ char *methodsNames[] = {
 	"PATCH"
 };
 
-char *protocolsNames[] = {
+const char *protocolsNames[] = {
 	"HTTP/1.1",
 	"HTTP/1.0",
- 	"HTTP/2.0",
- 	"HTTP/3"
+	"HTTP/2.0",
+	"HTTP/3"
 };
