@@ -1,5 +1,5 @@
 /*
- * Logswan 2.1.4
+ * Logswan 2.1.8
  * Copyright (c) 2015-2020, Frederic Cambus
  * https://www.logswan.org
  *
@@ -10,7 +10,7 @@
  * See LICENSE file for details.
  */
 
-char *continentsId[] = {
+const char *continentsId[] = {
 	"AF",
 	"AN",
 	"AS",
@@ -20,7 +20,7 @@ char *continentsId[] = {
 	"SA"
 };
 
-char *continentsNames[] = {
+const char *continentsNames[] = {
 	"Africa",
 	"Antarctica",
 	"Asia",
