@@ -1,16 +1,16 @@
 /*
- * Logswan 2.1.4
+ * Logswan 2.1.8
  * Copyright (c) 2015-2020, Frederic Cambus
  * https://www.logswan.org
  *
  * Created:      2015-05-31
- * Last Updated: 2019-01-19
+ * Last Updated: 2020-07-02
  *
  * Logswan is released under the BSD 2-Clause license.
  * See LICENSE file for details.
  */
 
-char *countriesId[] = {
+const char *countriesId[] = {
 	"AD",
 	"AE",
 	"AF",
@@ -18,7 +18,6 @@ char *countriesId[] = {
 	"AI",
 	"AL",
 	"AM",
-	"AN",
 	"AO",
 	"AQ",
 	"AR",
@@ -264,7 +263,7 @@ char *countriesId[] = {
 	"ZW"
 };
 
-char *countriesNames[] = {
+const char *countriesNames[] = {
 	"Andorra",
 	"United Arab Emirates",
 	"Afghanistan",
@@ -272,7 +271,6 @@ char *countriesNames[] = {
 	"Anguilla",
 	"Albania",
 	"Armenia",
-	"Netherlands Antilles",
 	"Angola",
 	"Antarctica",
 	"Argentina",
@@ -280,7 +278,7 @@ char *countriesNames[] = {
 	"Austria",
 	"Australia",
 	"Aruba",
-	"Aland",
+	"Aland Islands",
 	"Azerbaijan",
 	"Bosnia and Herzegovina",
 	"Barbados",
@@ -409,7 +407,7 @@ char *countriesNames[] = {
 	"Saint Martin",
 	"Madagascar",
 	"Marshall Islands",
-	"Macedonia",
+	"North Macedonia",
 	"Mali",
 	"Myanmar",
 	"Mongolia",
@@ -478,7 +476,7 @@ char *countriesNames[] = {
 	"El Salvador",
 	"Sint Maarten",
 	"Syria",
-	"Swaziland",
+	"Eswatini",
 	"Turks and Caicos Islands",
 	"Chad",
 	"French Southern Territories",
@@ -501,7 +499,7 @@ char *countriesNames[] = {
 	"United States",
 	"Uruguay",
 	"Uzbekistan",
-	"Vatican City",
+	"Vatican",
 	"Saint Vincent and the Grenadines",
 	"Venezuela",
 	"British Virgin Islands",
