@@ -1,24 +1,18 @@
 /*
- * Logswan 2.1.4
+ * Logswan 2.1.8
  * Copyright (c) 2015-2020, Frederic Cambus
  * https://www.logswan.org
  *
  * Created:      2015-05-31
- * Last Updated: 2020-03-16
+ * Last Updated: 2020-08-06
  *
  * Logswan is released under the BSD 2-Clause license.
  * See LICENSE file for details.
  */
 
-#define _XOPEN_SOURCE 600
-#define _POSIX_C_SOURCE 199309L
-#define _POSIX_SOURCE
-
-#include <sys/select.h>
 #include <sys/socket.h>
 #include <sys/stat.h>
 #include <sys/time.h>
-#include <sys/types.h>
 #include <arpa/inet.h>
 #include <err.h>
 #include <getopt.h>
@@ -33,9 +27,6 @@
 
 #ifdef HAVE_SECCOMP
 #include <sys/prctl.h>
-#include <sys/syscall.h>
-#include <linux/audit.h>
-#include <linux/filter.h>
 #include <linux/seccomp.h>
 #include "seccomp.h"
 #endif
@@ -82,7 +73,7 @@ struct HLL uniqueIPv4, uniqueIPv6;
 char *intputFile;
 char *db = NULL;
 
-void
+static void
 displayUsage()
 {
 	printf("USAGE: logswan [options] inputfile\n\n" \
@@ -187,10 +178,10 @@ main(int argc, char *argv[])
 
 		/* Detect if remote host is IPv4 or IPv6 */
 		if (parsedLine.remoteHost) { /* Do not feed NULL tokens to inet_pton */
-			if ((isIPv4 = inet_pton(AF_INET, parsedLine.remoteHost, &(ipv4.sin_addr)))) {
+			if ((isIPv4 = inet_pton(AF_INET, parsedLine.remoteHost, &ipv4.sin_addr))) {
 				isIPv6 = false;
 			} else {
-				isIPv6 = inet_pton(AF_INET6, parsedLine.remoteHost, &(ipv6.sin6_addr));
+				isIPv6 = inet_pton(AF_INET6, parsedLine.remoteHost, &ipv6.sin6_addr);
 
 				if (!isIPv6) {
 					results.invalidLines++;
@@ -221,6 +212,7 @@ main(int argc, char *argv[])
 
 		if (geoip) {
 			MMDB_entry_data_s entry_data;
+			memset(&entry_data, 0, sizeof(MMDB_entry_data_s));
 
 			lookup = MMDB_lookup_string(&geoip2, parsedLine.remoteHost, &gai_error, &mmdb_error);
 
